==> basil-cookie-0.0.1.tgz: package/test/cookiejar-test.js <==
/*!
 * Copyright 2011 Michael Phan-Ba
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * Module dependencies.
 */

var vows = require('vows')
  , assert = require('assert')
  , EventEmitter = require('events').EventEmitter
  , Cookie = require('../lib/index').Cookie
  , CookieJar = require('../lib/index').CookieJar;

/**
 * Vows tests.
 */

vows.describe('CookieJar').addBatch({
  'when adding cookies from RFC 2109 Example 1.5': {
    topic: function() {
      var jar = new CookieJar();
      jar.set('Customer', 'WILE_E_COYOTE', { path: '/acme' });
      jar.set('Part_Number', 'Rocket_Launcher_0001', { path: '/acme' });
      return jar;
    },
    'should be ok': function(topic) {
      var customer = topic.get('customer')
        , partNumber = topic.get('part_number');
      assert.equal(customer.value, 'WILE_E_COYOTE');
      assert.equal(customer.path, '/acme');
      assert.equal(partNumber.value, 'Rocket_Launcher_0001');
      assert.equal(partNumber.path, '/acme');
    },
    'should match case-insensitively': function(topic) {
      var customer = topic.get('CUSTOMER')
        , partNumber = topic.get('PART_NUMBER');
      assert.equal(customer.value, 'WILE_E_COYOTE');
      assert.equal(customer.path, '/acme');
      assert.equal(partNumber.value, 'Rocket_Launcher_0001');
      assert.equal(partNumber.path, '/acme');
    },
    'should save the cookie values in a hash': function(topic) {
      var hash = {};
      topic.saveCookieValues(hash);
      assert.equal(hash.customer, 'WILE_E_COYOTE');
      assert.equal(hash.part_number, 'Rocket_Launcher_0001');
    },
    'should return the cookie when removing': function(topic) {
      var cookie = topic.remove('customer');
      assert.equal(cookie.name, 'Customer');
      assert.equal(cookie.value, 'WILE_E_COYOTE');
      assert.equal(cookie.path, '/acme');
      assert.isUndefined(cookie.expires);
      assert.isUndefined(cookie.domain);
      assert.isFalse(cookie.secure);
      assert.isTrue(cookie.httpOnly);
      assert.isUndefined(topic.get('customer'));
    }
  },
  'when using cookies from RFC 2109 Example 1.5': {
    topic: function() {
      return new CookieJar([
        new Cookie('Customer', 'WILE_E_COYOTE', { path: '/acme' }),
        new Cookie('Part_Number', 'Rocket_Launcher_0001', { path: '/acme' })
      ]);
    },
    'should be ok': function(topic) {
      var customer = topic.get('customer')
        , partNumber = topic.get('part_number');
      assert.equal(customer.value, 'WILE_E_COYOTE');
      assert.equal(customer.path, '/acme');
      assert.equal(partNumber.value, 'Rocket_Launcher_0001');
      assert.equal(partNumber.path, '/acme');
    },
    'should match case-insensitively': function(topic) {
      var customer = topic.get('CUSTOMER')
        , partNumber = topic.get('PART_NUMBER');
      assert.equal(customer.value, 'WILE_E_COYOTE');
      assert.equal(customer.path, '/acme');
      assert.equal(partNumber.value, 'Rocket_Launcher_0001');
      assert.equal(partNumber.path, '/acme');
    },
    'should save the cookie values in a hash': function(topic) {
      var hash = {};
      topic.saveCookieValues(hash);
      assert.equal(hash.customer, 'WILE_E_COYOTE');
      assert.equal(hash.part_number, 'Rocket_Launcher_0001');
    },
    'should return the cookie when removing': function(topic) {
      var cookie = topic.remove('customer');
      assert.equal(cookie.name, 'Customer');
      assert.equal(cookie.value, 'WILE_E_COYOTE');
      assert.equal(cookie.path, '/acme');
      assert.isUndefined(cookie.expires);
      assert.isUndefined(cookie.domain);
      assert.isFalse(cookie.secure);
      assert.isTrue(cookie.httpOnly);
      assert.isUndefined(topic.get('customer'));
    }
  },
  'when using default options': {
    topic: function() {
      var jar = new CookieJar({
        path: '/path',
        expires: new Date(100),
        domain: '.example.com',
        secure: true,
        httpOnly: false
      });

      jar.set('Test', 'Hello World!');

      return jar.get('test');
    },
    'should be ok': function(topic) {
      assert.equal(topic.value, 'Hello World!');
      assert.equal(topic.path, '/path');
      assert.deepEqual(topic.expires, new Date(100));
      assert.equal(topic.domain, '.example.com');
      assert.isTrue(topic.secure);
      assert.isFalse(topic.httpOnly);
    }
  },
  'when setting the header': {
    topic: function() {
      var jar = new CookieJar;
      jar.set('Test', 'YES');
      return jar
    },
    'should set the header': function(topic) {
      var mock = mockReqRes(false, false);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.isTrue(mock.calledSetHeader === 1);
      assert.equal(mock.headerName, 'Set-Cookie');
      assert.equal(mock.headerValue, 'Test="YES"; path=/; httponly');
    }
  },
  'when setting the header with a secure cookie': {
    topic: function() {
      var jar = new CookieJar;
      jar.set('Test', 'YES', { secure: true });
      return jar
    },
    'should not set the header when insecure': function(topic) {
      var mock = mockReqRes(false, false);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.strictEqual(mock.calledSetHeader, 0);
    },
    'should set the header when secure': function(topic) {
      var mock = mockReqRes(true, false);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.strictEqual(mock.calledSetHeader, 1);
      assert.equal(mock.headerName, 'Set-Cookie');
      assert.equal(mock.headerValue, 'Test="YES"; path=/; secure; httponly');
    },
    'should set the header when proxy secure': function(topic) {
      var mock = mockReqRes(false, true);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.strictEqual(mock.calledSetHeader, 1);
      assert.equal(mock.headerName, 'Set-Cookie');
      assert.equal(mock.headerValue, 'Test="YES"; path=/; secure; httponly');
    },
    'should set the header when secure or proxy secure': function(topic) {
      var mock = mockReqRes(true, true);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.strictEqual(mock.calledSetHeader, 1);
      assert.equal(mock.headerName, 'Set-Cookie');
      assert.equal(mock.headerValue, 'Test="YES"; path=/; secure; httponly');
    }
  },
  'when setting the header with mixed cookies': {
    topic: function() {
      var jar = new CookieJar;
      jar.set('Test', 'YES', { secure: true });
      jar.set('Test2', 'NO');
      return jar
    },
    'should not set the secure cookie header when insecure': function(topic) {
      var mock = mockReqRes(false, false);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.strictEqual(mock.calledSetHeader, 1);
      assert.equal(mock.headerName, 'Set-Cookie');
      assert.equal(mock.headerValue, 'Test2="NO"; path=/; httponly');
    },
    'should set both cookie headers when secure': function(topic) {
      var mock = mockReqRes(true, false);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.strictEqual(mock.calledSetHeader, 1);
      assert.equal(mock.headerName, 'Set-Cookie');
      assert.include(mock.headerValue, 'Test="YES"; path=/; secure; httponly');
      assert.include(mock.headerValue, 'Test2="NO"; path=/; httponly');
    },
    'should set both cookie headers when proxy secure': function(topic) {
      var mock = mockReqRes(false, true);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.strictEqual(mock.calledSetHeader, 1);
      assert.equal(mock.headerName, 'Set-Cookie');
      assert.include(mock.headerValue, 'Test="YES"; path=/; secure; httponly');
      assert.include(mock.headerValue, 'Test2="NO"; path=/; httponly');
    },
    'should set both cookie headers when secure or proxy secure': function(topic) {
      var mock = mockReqRes(true, true);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.strictEqual(mock.calledSetHeader, 1);
      assert.include(mock.headerValue, 'Test="YES"; path=/; secure; httponly');
      assert.include(mock.headerValue, 'Test2="NO"; path=/; httponly');
    }
  }
}).export(module);

function mockReqRes(encrypted, proxyEncrypted) {
  var mock = {
      gotConnection: 0
    , gotEncrypted: 0
    , gotProxySecure: 0
    , calledSetHeader: 0
    , headerName: undefined
    , headerValue: undefined
    , socket: {
        get encrypted() {
          ++mock.gotEncrypted;
          return encrypted;
        },
        get proxySecure() {
          ++mock.gotProxySecure;
          return proxyEncrypted;
        }
      }
    , request: {
        get connection() {
          ++mock.gotConnection;
          return mock.socket;
        }
      }
    , response: {
        setHeader: function(name, value) {
          ++mock.calledSetHeader;
          mock.headerName = name;
          mock.headerValue = value;
        }
      }
  };

  return mock;
}

==> basil-cookie-0.3.0.tgz: package/test/cookiejar-test.js <==
/*!
 * Copyright 2011 Michael Phan-Ba
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * Module dependencies.
 */

var vows = require('vows')
  , assert = require('assert')
  , Cookie = require('../lib/index').Cookie
  , CookieJar = require('../lib/index').CookieJar
  , AesEncoder = require('../lib/encoders/aes').AesEncoder
  , signer = require('../lib/signers/hmac').signer;

/**
 * Vows tests.
 */

vows.describe('CookieJar').addBatch({
  'when parsing RFC 2109 Example 1.3': {
    topic: function() {
      return CookieJar.parseCookie('$Version="1"; Customer="WILE_E_COYOTE"; $Path="/acme"');
    },
    'should be ok': function(topic) {
      var cookie = topic.get('customer');
      assert.equal(cookie.value, 'WILE_E_COYOTE');
      assert.equal(cookie.path, '/acme');
    },
    'should match case-insensitively': function(topic) {
      var cookie = topic.get('CUSTOMER');
      assert.equal(cookie.value, 'WILE_E_COYOTE');
      assert.equal(cookie.path, '/acme');
    }
  },
  'when parsing RFC 2109 Example 1.5': {
    topic: function() {
      return CookieJar.parseCookie('$Version="1"; Customer="WILE_E_COYOTE"; $Path="/acme"; Part_Number="Rocket_Launcher_0001"; $Path="/acme"');
    },
    'should be ok': function(topic) {
      var customer = topic.get('customer')
        , partNumber = topic.get('part_number');
      assert.equal(customer.value, 'WILE_E_COYOTE');
      assert.equal(customer.path, '/acme');
      assert.equal(partNumber.value, 'Rocket_Launcher_0001');
      assert.equal(partNumber.path, '/acme');
    },
    'should match case-insensitively': function(topic) {
      var customer = topic.get('CUSTOMER')
        , partNumber = topic.get('PART_NUMBER');
      assert.equal(customer.value, 'WILE_E_COYOTE');
      assert.equal(customer.path, '/acme');
      assert.equal(partNumber.value, 'Rocket_Launcher_0001');
      assert.equal(partNumber.path, '/acme');
    }
  },
  'when parsing a bad cookie': {
    topic: function() {
      return CookieJar.parseCookie('Test=%abc');
    },
    'should be ok': function(topic) {
      var cookie = topic.get('test');
      assert.equal(cookie.value, '%abc');
    }
  },
  'when parsing with no cookie': {
    'should return undefined': function(topic) {
      assert.isUndefined(CookieJar.parseCookie(''));
    }
  },
  'when parsing with options with RFC 2109 Example 1.5': {
    topic: function() {
      var options = {
        path: '/path',
        expires: new Date(100),
        domain: '.example.com',
        secure: true,
        httpOnly: false
      };
      return [options, CookieJar.parseCookie('$Version="1"; Customer="WILE_E_COYOTE"; $Path="/acme"; Part_Number="Rocket_Launcher_0001"; $Path="/acme"', options)];
    },
    'should pass through options to CookieJar': function(topic) {
      var options = topic[0], jar = topic[1];
      assert.deepEqual(jar.options, options);
    },
    'should save cookie info in request.cookieJar': function(topic) {
      var options = topic[0]
        , jar = topic[1]
        , customer = jar.get('customer')
        , partNumber = jar.get('part_number');
      assert.equal(customer.name, 'Customer');
      assert.equal(customer.value, 'WILE_E_COYOTE');
      assert.equal(customer.path, '/acme');
      assert.equal(partNumber.name, 'Part_Number');
      assert.equal(partNumber.value, 'Rocket_Launcher_0001');
      assert.equal(partNumber.path, '/acme');
    }
  },
  'when adding cookies': {
    topic: function() {
      return (new CookieJar()).set('Test', 'Hello');
    },
    'should return the added cookie': function(topic) {
      assert.equal(topic.name, 'Test');
      assert.equal(topic.value, 'Hello');
    }
  },
  'when removing cookies': {
    topic: function() {
      var jar = new CookieJar();
      jar.set('Test', 'Hello');
      return jar.remove('test');
    },
    'should return the removed cookie': function(topic) {
      assert.equal(topic.name, 'Test');
      assert.equal(topic.value, 'Hello');
    }
  },
  'when adding cookies from RFC 2109 Example 1.5': {
    topic: function() {
      var jar = new CookieJar();
      jar.set('Customer', 'WILE_E_COYOTE', { path: '/acme' });
      jar.set('Part_Number', 'Rocket_Launcher_0001', { path: '/acme' });
      return jar;
    },
    'should be ok': function(topic) {
      var customer = topic.get('customer')
        , partNumber = topic.get('part_number');
      assert.equal(customer.value, 'WILE_E_COYOTE');
      assert.equal(customer.path, '/acme');
      assert.equal(partNumber.value, 'Rocket_Launcher_0001');
      assert.equal(partNumber.path, '/acme');
    },
    'should match case-insensitively': function(topic) {
      var customer = topic.get('CUSTOMER')
        , partNumber = topic.get('PART_NUMBER');
      assert.equal(customer.value, 'WILE_E_COYOTE');
      assert.equal(customer.path, '/acme');
      assert.equal(partNumber.value, 'Rocket_Launcher_0001');
      assert.equal(partNumber.path, '/acme');
    },
    'should save the cookie values in a hash': function(topic) {
      var hash = {};
      topic.saveCookieValues(hash);
      assert.equal(hash.customer, 'WILE_E_COYOTE');
      assert.equal(hash.part_number, 'Rocket_Launcher_0001');
    },
    'should return the cookie when removing': function(topic) {
      var cookie = topic.remove('customer');
      assert.equal(cookie.name, 'Customer');
      assert.equal(cookie.value, 'WILE_E_COYOTE');
      assert.equal(cookie.path, '/acme');
      assert.isUndefined(cookie.expires);
      assert.isUndefined(cookie.domain);
      assert.isFalse(cookie.secure);
      assert.isTrue(cookie.httpOnly);
      assert.isUndefined(topic.get('customer'));
    }
  },
  'when using cookies from RFC 2109 Example 1.5': {
    topic: function() {
      return new CookieJar([
        new Cookie('Customer', 'WILE_E_COYOTE', { path: '/acme' }),
        new Cookie('Part_Number', 'Rocket_Launcher_0001', { path: '/acme' })
      ]);
    },
    'should be ok': function(topic) {
      var customer = topic.get('customer')
        , partNumber = topic.get('part_number');
      assert.equal(customer.value, 'WILE_E_COYOTE');
      assert.equal(customer.path, '/acme');
      assert.equal(partNumber.value, 'Rocket_Launcher_0001');
      assert.equal(partNumber.path, '/acme');
    },
    'should match case-insensitively': function(topic) {
      var customer = topic.get('CUSTOMER')
        , partNumber = topic.get('PART_NUMBER');
      assert.equal(customer.value, 'WILE_E_COYOTE');
      assert.equal(customer.path, '/acme');
      assert.equal(partNumber.value, 'Rocket_Launcher_0001');
      assert.equal(partNumber.path, '/acme');
    },
    'should save the cookie values in a hash': function(topic) {
      var hash = {};
      topic.saveCookieValues(hash);
      assert.equal(hash.customer, 'WILE_E_COYOTE');
      assert.equal(hash.part_number, 'Rocket_Launcher_0001');
    },
    'should return the cookie when removing': function(topic) {
      var cookie = topic.remove('customer');
      assert.equal(cookie.name, 'Customer');
      assert.equal(cookie.value, 'WILE_E_COYOTE');
      assert.equal(cookie.path, '/acme');
      assert.isUndefined(cookie.expires);
      assert.isUndefined(cookie.domain);
      assert.isFalse(cookie.secure);
      assert.isTrue(cookie.httpOnly);
      assert.isUndefined(topic.get('customer'));
    }
  },
  'when using default options': {
    topic: function() {
      var jar = new CookieJar({
        path: '/path',
        expires: new Date(100),
        domain: '.example.com',
        secure: true,
        httpOnly: false
      });

      jar.set('Test', 'Hello World!');

      return jar.get('test');
    },
    'should be ok': function(topic) {
      assert.equal(topic.value, 'Hello World!');
      assert.equal(topic.path, '/path');
      assert.deepEqual(topic.expires, new Date(100));
      assert.equal(topic.domain, '.example.com');
      assert.isTrue(topic.secure);
      assert.isFalse(topic.httpOnly);
    }
  },
  'when using options.map': {
    topic: function() {
      var jar = new CookieJar({
        map: {
          encrypt: {
            encoder: new AesEncoder({ secret: 'xyzzy' })
          }
        }
      });

      jar.set('Test', 'Hello World!');
      jar.set('Encrypt', 'Hello World!');

      return jar;
    },
    'should use the default encoder when not mapped': function(topic) {
      var value = topic.get('test').toString();
      assert.equal(value, 'Test="Hello World!"; path=/; httponly');
    },
    'should not the default encoder when mapped': function(topic) {
      var value = topic.get('encrypt').toString();
      assert.notEqual(value, 'Encrypt="Hello World!"; path=/; httponly');
    }
  },
  'when parsing with a signer': {
    topic: function() {
      return CookieJar.parseCookie('Unsigned=null; Signed="EpdmDg.+emMs8wGeIuiR821BDZ2aBMLhTs.2hta6q40g0.Hello World!"; Expired="uKhXIA.4s5MKqHTaszlqBP2CQJycUrPg1E.grqyodrl.Hello World!"; Tampered="EpdmDg.+emMs8wGeIuiR821BDZ2aBMLhTs.2hta6q40g0.Goodbye World!"', {
        signer: signer
      });
    },
    'should pass valid signed cookies': function(topic) {
      assert.equal(topic.get('signed').value, 'Hello World!');
    },
    'should assign unsigned cookies a value of undefined': function(topic) {
      assert.isUndefined(topic.get('unsigned').value);
    },
    'should assign expired cookies a value of undefined': function(topic) {
      assert.isUndefined(topic.get('expired').value);
    },
    'should assign tampered cookies a value of undefined': function(topic) {
      assert.isUndefined(topic.get('tampered').value);
    }
  },
  'when setting the header': {
    topic: function() {
      var jar = new CookieJar;
      jar.set('Test', 'YES');
      return jar
    },
    'should set the header': function(topic) {
      var mock = mockReqRes(false, false);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.isTrue(mock.calledSetHeader === 1);
      assert.equal(mock.headerName, 'Set-Cookie');
      assert.equal(mock.headerValue, 'Test="YES"; path=/; httponly');
    }
  },
  'when setting the header with a secure cookie': {
    topic: function() {
      var jar = new CookieJar;
      jar.set('Test', 'YES', { secure: true });
      return jar
    },
    'should not set the header when insecure': function(topic) {
      var mock = mockReqRes(false, false);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.strictEqual(mock.calledSetHeader, 0);
    },
    'should set the header when secure': function(topic) {
      var mock = mockReqRes(true, false);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.strictEqual(mock.calledSetHeader, 1);
      assert.equal(mock.headerName, 'Set-Cookie');
      assert.equal(mock.headerValue, 'Test="YES"; path=/; secure; httponly');
    },
    'should set the header when proxy secure': function(topic) {
      var mock = mockReqRes(false, true);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.strictEqual(mock.calledSetHeader, 1);
      assert.equal(mock.headerName, 'Set-Cookie');
      assert.equal(mock.headerValue, 'Test="YES"; path=/; secure; httponly');
    },
    'should set the header when secure or proxy secure': function(topic) {
      var mock = mockReqRes(true, true);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.strictEqual(mock.calledSetHeader, 1);
      assert.equal(mock.headerName, 'Set-Cookie');
      assert.equal(mock.headerValue, 'Test="YES"; path=/; secure; httponly');
    }
  },
  'when setting the header with mixed cookies': {
    topic: function() {
      var jar = new CookieJar;
      jar.set('Test', 'YES', { secure: true });
      jar.set('Test2', 'NO');
      return jar
    },
    'should not set the secure cookie header when insecure': function(topic) {
      var mock = mockReqRes(false, false);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.strictEqual(mock.calledSetHeader, 1);
      assert.equal(mock.headerName, 'Set-Cookie');
      assert.equal(mock.headerValue, 'Test2="NO"; path=/; httponly');
    },
    'should set both cookie headers when secure': function(topic) {
      var mock = mockReqRes(true, false);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.strictEqual(mock.calledSetHeader, 1);
      assert.equal(mock.headerName, 'Set-Cookie');
      assert.include(mock.headerValue, 'Test="YES"; path=/; secure; httponly');
      assert.include(mock.headerValue, 'Test2="NO"; path=/; httponly');
    },
    'should set both cookie headers when proxy secure': function(topic) {
      var mock = mockReqRes(false, true);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.strictEqual(mock.calledSetHeader, 1);
      assert.equal(mock.headerName, 'Set-Cookie');
      assert.include(mock.headerValue, 'Test="YES"; path=/; secure; httponly');
      assert.include(mock.headerValue, 'Test2="NO"; path=/; httponly');
    },
    'should set both cookie headers when secure or proxy secure': function(topic) {
      var mock = mockReqRes(true, true);

      topic.setHeader(mock.request, mock.response);

      assert.isTrue(mock.gotConnection >= 1);
      assert.strictEqual(mock.calledSetHeader, 1);
      assert.include(mock.headerValue, 'Test="YES"; path=/; secure; httponly');
      assert.include(mock.headerValue, 'Test2="NO"; path=/; httponly');
    }
  }
}).export(module);

function mockReqRes(encrypted, proxyEncrypted) {
  var mock = {
      gotConnection: 0
    , gotEncrypted: 0
    , gotProxySecure: 0
    , calledSetHeader: 0
    , headerName: undefined
    , headerValue: undefined
    , socket: {
        get encrypted() {
          ++mock.gotEncrypted;
          return encrypted;
        },
        get proxySecure() {
          ++mock.gotProxySecure;
          return proxyEncrypted;
        }
      }
    , request: {
        get connection() {
          ++mock.gotConnection;
          return mock.socket;
        }
      }
    , response: {
        setHeader: function(name, value) {
          ++mock.calledSetHeader;
          mock.headerName = name;
          mock.headerValue = value;
        }
      }
  };

  return mock;
}
